@@ -70,6 +70,17 @@ def _ldp_container_representation(id, container_permissions=None, value=None):
     return represented_object
 
 
+def _serialize_rdf_fields(obj, data, include_context=False):
+    rdf_type = Model.get_meta(obj, 'rdf_type', None)
+    rdf_context = Model.get_meta(obj, 'rdf_context', None)
+    if rdf_type is not None:
+        data['@type'] = rdf_type
+    if include_context and rdf_context is not None:
+        data['@context'] = rdf_context
+
+    return data
+
+
 class LDListMixin:
     '''A Mixin for serializing containers into JSONLD format'''
     child_attr = 'child'
@@ -259,12 +270,18 @@ class JsonLdField(HyperlinkedRelatedField):
 
 
 class JsonLdRelatedField(JsonLdField):
+    def use_pk_only_optimization(self):
+        return False
+
     def to_representation(self, value):
         try:
+            include_context = False
             if Model.is_external(value):
-                return {'@id': value.urlid}
+                data = {'@id': value.urlid}
             else:
-                return {'@id': super().to_representation(value)}
+                include_context = True
+                data = {'@id': super().to_representation(value)}
+            return _serialize_rdf_fields(value, data, include_context=include_context)
         except ImproperlyConfigured:
             return value.pk
 
@@ -338,21 +355,11 @@ class LDPSerializer(HyperlinkedModelSerializer):
             fields = super().get_default_field_names(declared_fields, model_info)
         return fields + list(getattr(self.Meta, 'extra_fields', []))
 
-    def _serialize_rdf_fields(self, obj, data):
-        rdf_type = Model.get_meta(obj, 'rdf_type', None)
-        rdf_context = Model.get_meta(obj, 'rdf_context', None)
-        if rdf_type is not None:
-            data['@type'] = rdf_type
-        if rdf_context is not None:
-            data['@context'] = rdf_context
-
-        return data
-
     def to_representation(self, obj):
-        # external Models should only be returned with an id (on GET)
-        if self.context['request'].method == 'GET' and Model.is_external(obj):
+        # external Models should only be returned with rdf values
+        if Model.is_external(obj):
             data = {'@id': obj.urlid}
-            return self._serialize_rdf_fields(obj, data)
+            return _serialize_rdf_fields(obj, data)
 
         cache_vary = str(self.context['request'].user)
         if self.with_cache and hasattr(obj, 'urlid'):
@@ -373,7 +380,7 @@ class LDPSerializer(HyperlinkedModelSerializer):
             data['@id'] = data.pop('urlid')['@id']
         if not '@id' in data:
             data['@id'] = '{}{}'.format(settings.SITE_URL, Model.resource(obj))
-        data = self._serialize_rdf_fields(obj, data)
+        data = _serialize_rdf_fields(obj, data, include_context=True)
         data['permissions'] = Model.get_permissions(obj, self.context,
                                                     ['view', 'change', 'control', 'delete'])
 
@@ -788,7 +795,8 @@ class LDPSerializer(HyperlinkedModelSerializer):
             manager = getattr(instance, attr)
             oldObj = manager._meta.model.objects.get(**kwargs)
         else:
-            oldObj = getattr(instance, attr)
+            related_model = relation_info.related_model
+            oldObj = related_model.objects.get(**kwargs)
 
         value = self.update(instance=oldObj, validated_data=value)
         return value
